@@ -1,12 +1,36 @@
+/*	$Id: OakFiles.c,v 1.15 2000/09/23 19:40:44 ooc-devel Exp $	*/
+/*  Oakwood compliant file access.
+    Copyright (C) 1997, 1998, 2000  Michael van Acken, Juergen Zimmermann
+
+    This module is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Lesser General Public License
+    as published by the Free Software Foundation; either version 2 of
+    the License, or (at your option) any later version.
+
+    This module is distributed in the hope that it will be useful, but
+    WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Lesser General Public License for more details.
+
+    You should have received a copy of the GNU Lesser General Public
+    License along with OOC. If not, write to the Free Software Foundation,
+    59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+*/
 #include "__oo2c.h"
+#include "__config.h"
 #define _POSIX_SOURCE  /* file uses POSIX.1 functions */
 
 #include <fcntl.h>
 #include <errno.h>
 #include <stdio.h>
-#include <unistd.h> 
 #include <stdlib.h>
+#include <string.h>
 #include <sys/stat.h>
+#if HAVE_UNISTD_H
+#include <unistd.h>
+#elif HAVE_IO_H
+#include <io.h>
+#endif
 #if TIME_WITH_SYS_TIME
 # include <sys/time.h>
 # include <time.h>
@@ -22,6 +46,14 @@
 #define O_BINARY 0
 #endif
 
+#ifdef __MINGW32__
+#define MODE_CREATE_FILE (S_IREAD | S_IWRITE)
+#define MODE_PURGE_FILE (S_IREAD | S_IWRITE)
+#else
+#define MODE_CREATE_FILE (S_IRUSR|S_IWUSR|S_IRGRP|S_IWGRP|S_IROTH|S_IWOTH)
+#define MODE_PURGE_FILE (S_IRUSR|S_IWUSR)
+#endif
+
 #include "__config.h"
 #include "__mini_gc.h"
 #include "OakFiles.h"
@@ -46,13 +78,13 @@ static void finalize(void *obj, void *client_data);
 #define sizeBuffer (4*largeBlock)
 #define maxFilenameLen 256
 
-typedef CHAR (* FileName);
+typedef OOC_CHAR (* FileName);
 
 static int maxFdUsed = 10; /* max. number of physical files used */
-static OakFiles_File openFiles = NULL; /* there are no files at startup */
+static OakFiles__File openFiles = NULL; /* there are no files at startup */
 static int fdInUse = 0; /* no fd's used by this module at startup*/
 static int swapBytes = 0; /* do not swap bytes on write */
-BOOLEAN OakFiles_permanentClose = 0;
+OOC_BOOLEAN OakFiles_permanentClose = 0;
 
 
 static _ModId _mid;
@@ -65,7 +97,7 @@ static const struct {
 } _n0 = {9, NULL, {"OakFiles"}};
 static struct _MD OakFiles__md = {
   NULL, 
-  &Kernel_ModuleDesc__td.td, 
+  &Kernel__ModuleDesc_td.td, 
   {
     NULL, 
     (const unsigned char*)_n0.name, 
@@ -77,26 +109,26 @@ static struct _MD OakFiles__md = {
 
 
 
-static void CreateTmpName(CHAR *name) {
+static void CreateTmpName(OOC_CHAR *name) {
 /* create a name for a temporary file */
-  CHAR *tmp = NULL;
+  OOC_CHAR *tmp = NULL;
   
-  tmp = (CHAR*)tmpnam(NULL);
+  tmp = (OOC_CHAR*)tmpnam(NULL);
   _string_copy(name, tmp, maxFilenameLen);
 }
 
 
-static void ClearBuffer(OakFiles_Buffer *buf) {
+static void ClearBuffer(OakFiles__Buffer *buf) {
   buf->start = 0;
   buf->end = 0;
   buf->read = 1;
 }
 
-static OakFiles_File NewFile(const CHAR *name) {
+static OakFiles__File NewFile(const OOC_CHAR *name) {
 /* Allocate memory for a new File structure and initialize it. */
-  OakFiles_File newfile;
+  OakFiles__File newfile;
   
-  newfile = (OakFiles_File)GC_malloc_atomic(sizeof(OakFiles_FileDesc));
+  newfile = (OakFiles__File)GC_malloc_atomic(sizeof(OakFiles__FileDesc));
 #if USE_GC
   {
     GC_finalization_proc ofn;
@@ -124,7 +156,7 @@ static OakFiles_File NewFile(const CHAR *name) {
   return newfile;
 }
 
-static void DeallocateFileDesc(OakFiles_File file) {
+static void DeallocateFileDesc(OakFiles__File file) {
 /* Close the file associated with 'file' and release 'fd' */
   if (file->flagValid == 1) {
     int res;
@@ -143,7 +175,7 @@ static void DeallocateFileDesc(OakFiles_File file) {
 
 static void FreeFileDesc(void);
 
-static int GetFileDesc(OakFiles_File file, int newfile) {
+static int GetFileDesc(OakFiles__File file, int newfile) {
   /* allocate a file descriptor for 'file'.
     'newfile' reflects the open mode:
      1: Files.New (create new file)
@@ -179,8 +211,7 @@ static int GetFileDesc(OakFiles_File file, int newfile) {
     /* Create a new file. The Unix permissions for the new file are
       set to rw-rw-rw */
     do
-      fd = open((char*)fn,(O_CREAT|O_TRUNC|O_RDWR|O_BINARY),
-		(S_IRUSR|S_IWUSR|S_IRGRP|S_IWGRP|S_IROTH|S_IWOTH));
+      fd = open((char*)fn,(O_CREAT|O_TRUNC|O_RDWR|O_BINARY), MODE_CREATE_FILE);
     while ((fd == -1) && (errno == EINTR));
     
     if ((fd == -1) && ((errno == EMFILE) || (errno == ENFILE)) && (fdInUse != 0)) {
@@ -235,7 +266,7 @@ static int GetFileDesc(OakFiles_File file, int newfile) {
 }
 
 
-static void AllocateFileDesc(OakFiles_File file) {
+static void AllocateFileDesc(OakFiles__File file) {
   if (file->flagValid == 1)
     file->flagMark = 0; /* touch */
   else if (GetFileDesc(file,0) == 0) {
@@ -246,7 +277,7 @@ static void AllocateFileDesc(OakFiles_File file) {
 
 
 static void FreeFileDesc(void) {
-  OakFiles_File walk = openFiles;
+  OakFiles__File walk = openFiles;
   do {
     if ((walk->flagValid == 1) && (walk->flagKeepFd == 0)) {
       if (walk->flagMark == 1) {
@@ -263,12 +294,12 @@ static void FreeFileDesc(void) {
 }
 
 
-static void InsertFile(OakFiles_File file) {
+static void InsertFile(OakFiles__File file) {
   if (openFiles == NULL) {
     openFiles = file;
     file->next=file;
   } else {
-    OakFiles_File oldEnd = openFiles;
+    OakFiles__File oldEnd = openFiles;
     
     while (oldEnd->next != openFiles) {
       oldEnd = oldEnd->next;
@@ -281,9 +312,9 @@ static void InsertFile(OakFiles_File file) {
 
 
 #if USE_GC
-static BOOLEAN StillInUse(OakFiles_File file)
+static OOC_BOOLEAN StillInUse(OakFiles__File file)
 {
-  OakFiles_File walk = openFiles;
+  OakFiles__File walk = openFiles;
 
   while ((walk != NULL) && (walk != file) && (walk->next != openFiles))
     walk = walk->next;
@@ -291,13 +322,13 @@ static BOOLEAN StillInUse(OakFiles_File file)
 }
 #endif
 
-static void RemoveFile(OakFiles_File file) {
+static void RemoveFile(OakFiles__File file) {
   DeallocateFileDesc(file);
   if (openFiles != NULL) {
     if (file->next == file) {
       openFiles = NULL;
     } else {
-      OakFiles_File walk = openFiles;
+      OakFiles__File walk = openFiles;
       
       while ((walk->next != file) && (walk->next != openFiles)) {
 	walk = walk->next;
@@ -314,7 +345,7 @@ static void RemoveFile(OakFiles_File file) {
 }
 
 
-static LONGINT WriteToFile(OakFiles_File f, LONGINT pos, BYTE *adr, LONGINT n) {
+static LONGINT WriteToFile(OakFiles__File f, LONGINT pos, OOC_BYTE *adr, LONGINT n) {
   /* WriteToFile (f, pos, adr, n) writes the first n bytes starting at
     memory address adr to file f at position pos.
     f.pos is updated accordingly.
@@ -337,7 +368,7 @@ static LONGINT WriteToFile(OakFiles_File f, LONGINT pos, BYTE *adr, LONGINT n) {
   }
 }
 
-static LONGINT ReadFromFile(OakFiles_File f, LONGINT pos, BYTE *adr, LONGINT n) {
+static LONGINT ReadFromFile(OakFiles__File f, LONGINT pos, OOC_BYTE *adr, LONGINT n) {
   /* ReadFromFile (f, pos, buf, n) reads the first n bytes at
     position pos from file f and stores them at memory address adr.
     f.pos is updated accordingly.
@@ -361,7 +392,7 @@ static LONGINT ReadFromFile(OakFiles_File f, LONGINT pos, BYTE *adr, LONGINT n)
   }
 }
 
-static void Flush(OakFiles_File f) {
+static void Flush(OakFiles__File f) {
   LONGINT res;
   
   if ((f->buffer.read == 0) && (f->buffer.end != f->buffer.start)) {
@@ -372,10 +403,10 @@ static void Flush(OakFiles_File f) {
 }
 
 
-static void SwapOrder(BYTE x[], LONGINT len) {
+static void SwapOrder(OOC_BYTE x[], LONGINT len) {
   if (swapBytes) {
     LONGINT i,j;
-    BYTE c;
+    OOC_BYTE c;
     /* swap the bytes */
     i=0; j=len-1;
     while (i < j) {
@@ -385,7 +416,7 @@ static void SwapOrder(BYTE x[], LONGINT len) {
   }
 }
 
-static void InitSwap(BYTE x[]) {
+static void InitSwap(OOC_BYTE x[]) {
   swapBytes=(x[0] != 1);
 /*
   if (swapBytes)
@@ -398,16 +429,16 @@ static void InitSwap(BYTE x[]) {
 
 
 
-OakFiles_File OakFiles_Base(struct OakFiles_Rider *r) {
+OakFiles__File OakFiles_Base(struct OakFiles__Rider *r) {
   if (r != NULL)
     return r->file;
   else
     return NULL;
 }
 
-static void CloseDown(OakFiles_File f) {
+static void CloseDown(OakFiles__File f) {
 /* CloseDown (f) writes back the file buffers of f. The file is no more
-   accessible by its handle f or the struct OakFiles_Riders positioned on it. */
+   accessible by its handle f or the struct OakFiles__Riders positioned on it. */
   INTEGER res;
 
 #if USE_GC
@@ -425,14 +456,14 @@ static void CloseDown(OakFiles_File f) {
 #endif
 }
 
-void OakFiles_Close(OakFiles_File *f) {
+void OakFiles_Close(OakFiles__File *f) {
 /* Close (f) writes back the file buffers of f. The file is still accessible by
-  its handle f and the struct OakFiles_Riders positioned on it. If a file is not modified it
+  its handle f and the struct OakFiles__Riders positioned on it. If a file is not modified it
   is not necessary to close it.
   
   Note: The above holds only for permanentClose=0, otherwise the buffers
   are flushed and the file handle is deallocated (and `f' is set to NIL).
-  All struct OakFiles_Riders on this file will become invalid.  This behaviour and the
+  All struct OakFiles__Riders on this file will become invalid.  This behaviour and the
   variable permanentClose are not part of the Oakwood guidelines. */
   Flush(*f);
   if (OakFiles_permanentClose) {
@@ -454,7 +485,7 @@ void OakFiles_Close(OakFiles_File *f) {
 }
 
 
-void OakFiles_Delete(const CHAR *name, INTEGER *res) {
+void OakFiles_Delete(const OOC_CHAR *name, INTEGER *res) {
   *res = (-unlink((const char*)name));
 }
 
@@ -477,7 +508,7 @@ int get_o2time (long int sec, LONGINT *t, LONGINT *d) {
     return -1;
 }
 
-void OakFiles_GetDate(OakFiles_File f, LONGINT *t, LONGINT *d) {
+void OakFiles_GetDate(OakFiles__File f, LONGINT *t, LONGINT *d) {
 /* GetDate (f, t, d) returns the time t and date d of the
    last modification of file f.
    The encoding is:
@@ -501,7 +532,7 @@ void OakFiles_GetDate(OakFiles_File f, LONGINT *t, LONGINT *d) {
 }
 
 
-LONGINT OakFiles_Length(OakFiles_File f) {
+LONGINT OakFiles_Length(OakFiles__File f) {
   int res;
   struct stat attr;
   FileName name;
@@ -519,8 +550,8 @@ LONGINT OakFiles_Length(OakFiles_File f) {
 }
 
 
-OakFiles_File OakFiles_New(const CHAR *name) {
-  OakFiles_File f = NULL;
+OakFiles__File OakFiles_New(const OOC_CHAR *name) {
+  OakFiles__File f = NULL;
   
   f = NewFile(name);
   
@@ -534,8 +565,8 @@ OakFiles_File OakFiles_New(const CHAR *name) {
 }
 
 
-OakFiles_File OakFiles_Old(const CHAR *name) {
-  OakFiles_File f = NULL;
+OakFiles__File OakFiles_Old(const OOC_CHAR *name) {
+  OakFiles__File f = NULL;
 
   f = NewFile(name);
   f->flagReg = 1;
@@ -549,7 +580,7 @@ OakFiles_File OakFiles_Old(const CHAR *name) {
 }
 
 
-LONGINT OakFiles_Pos(struct OakFiles_Rider *r) {
+LONGINT OakFiles_Pos(struct OakFiles__Rider *r) {
   if (r != NULL)
     return r->pos;
   else
@@ -557,7 +588,7 @@ LONGINT OakFiles_Pos(struct OakFiles_Rider *r) {
 }
 
 /*
-void OakFiles_Purge(OakFiles_File f) {
+void OakFiles_Purge(OakFiles__File f) {
   int res;
   
   AllocateFileDesc(f);
@@ -565,7 +596,7 @@ void OakFiles_Purge(OakFiles_File f) {
   ClearBuffer(&(f->buffer));
 }
 */
-void OakFiles_Purge(OakFiles_File f)
+void OakFiles_Purge(OakFiles__File f)
 {
    int fd;
    FileName fn= NULL;
@@ -584,8 +615,7 @@ void OakFiles_Purge(OakFiles_File f)
    }
    
    do {
-      fd = open((char*)(&(f->name)),(O_TRUNC|O_RDWR|O_BINARY),
-		(S_IRUSR|S_IWUSR));
+      fd = open((char*)(f->name),(O_TRUNC|O_RDWR|O_BINARY), MODE_PURGE_FILE);
    } while ((fd == -1) && (errno == EINTR));
    
    if (fd == -1) {
@@ -601,8 +631,8 @@ void OakFiles_Purge(OakFiles_File f)
    f->pos=-1;
 }
 
-void OakFiles_ReadBytes(struct OakFiles_Rider *r, BYTE *x, LONGINT n) {
-  OakFiles_File f;
+void OakFiles_ReadBytes(struct OakFiles__Rider *r, OOC_BYTE *x, LONGINT n) {
+  OakFiles__File f;
   LONGINT n0;
   
   f = r->file;
@@ -639,8 +669,8 @@ void OakFiles_ReadBytes(struct OakFiles_Rider *r, BYTE *x, LONGINT n) {
   }
 }
 
-void OakFiles_WriteBytes(struct OakFiles_Rider *r, BYTE *x, LONGINT n) {
-  OakFiles_File f;
+void OakFiles_WriteBytes(struct OakFiles__Rider *r, OOC_BYTE *x, LONGINT n) {
+  OakFiles__File f;
 
   f = r->file;
   if ((!f->buffer.read) &&
@@ -669,9 +699,9 @@ void OakFiles_WriteBytes(struct OakFiles_Rider *r, BYTE *x, LONGINT n) {
   }
 }
 
-static OakFiles_File regFile = NULL;
+static OakFiles__File regFile = NULL;
 
-void OakFiles_Register(OakFiles_File f) {
+void OakFiles_Register(OakFiles__File f) {
 /* Register (f) enters the file f into the directory together with the name
    provided in the operation New that created f. The file buffers are
    written back. Any existing mapping of this name to another file is
@@ -680,8 +710,8 @@ void OakFiles_Register(OakFiles_File f) {
   LONGINT oldpos;
   INTEGER dummy;
   int res;
-  BYTE buffer[bufSize];
-  BOOLEAN err;
+  OOC_BYTE buffer[bufSize];
+  OOC_BOOLEAN err;
   LONGINT n;
   
   if (regFile == NULL) {
@@ -725,14 +755,14 @@ void OakFiles_Register(OakFiles_File f) {
     err = 0;
     while(1) {
       do
-	n = read (f->fd, &buffer, bufSize);
+	n = read (f->fd, buffer, bufSize);
       while ((n == -1) && (errno == EINTR));
       if (n == -1) {
 	err = 1;
 	goto _loopend;
       }
       do
-	n = write (regFile->fd, &buffer, n);
+	n = write (regFile->fd, buffer, n);
       while ((n == -1) && (errno == EINTR));
       if (n == -1) {
 	err = 1;
@@ -757,11 +787,11 @@ void OakFiles_Register(OakFiles_File f) {
   }
 }
 
-void OakFiles_Rename(const CHAR *old, const CHAR *newname, INTEGER *res) {
+void OakFiles_Rename(const OOC_CHAR *old, const OOC_CHAR *newname, INTEGER *res) {
   *res = -(rename((const char*)old,(const char*)newname));
 }
 
-void OakFiles_Set(struct OakFiles_Rider *r, OakFiles_File f, LONGINT pos)
+void OakFiles_Set(struct OakFiles__Rider *r, OakFiles__File f, LONGINT pos)
 {
   if (r != NULL) {
     r->file=f;
@@ -770,24 +800,24 @@ void OakFiles_Set(struct OakFiles_Rider *r, OakFiles_File f, LONGINT pos)
     r->eof = 0;
     r->pos = pos;
   } else {
-    fprintf(stderr,"OakFiles.Set: struct OakFiles_Rider not valid\n");
+    fprintf(stderr,"OakFiles.Set: struct OakFiles__Rider not valid\n");
   }
 }
 
-static void WriteBytesSwap(struct OakFiles_Rider *r, BYTE *x, LONGINT n) {
+static void WriteBytesSwap(struct OakFiles__Rider *r, OOC_BYTE *x, LONGINT n) {
   SwapOrder(x,n);
   OakFiles_WriteBytes(r,x,n);
 }
 
-static void ReadBytesSwap(struct OakFiles_Rider *r, BYTE *x, LONGINT n) {
+static void ReadBytesSwap(struct OakFiles__Rider *r, OOC_BYTE *x, LONGINT n) {
   OakFiles_ReadBytes(r,x,n);
   SwapOrder(x,n);
 }
 
 
 
-void OakFiles_Write (struct OakFiles_Rider *r, BYTE x) {
-/* Write (r, x) writes the byte x to struct OakFiles_Rider r and advances r accordingly. */
+void OakFiles_Write (struct OakFiles__Rider *r, OOC_BYTE x) {
+/* Write (r, x) writes the byte x to struct OakFiles__Rider r and advances r accordingly. */
   if ((r->file->buffer.read == 0) &&
      (r->file->buffer.start <= r->pos) &&
      (r->pos <= r->file->buffer.end) &&
@@ -799,65 +829,65 @@ void OakFiles_Write (struct OakFiles_Rider *r, BYTE x) {
     if (r->file->buffer.end < r->pos)
       r->file->buffer.end = r->pos;
   } else {
-    OakFiles_WriteBytes(r,&x,sizeof(BYTE));
+    OakFiles_WriteBytes(r,&x,sizeof(OOC_BYTE));
   }
 }
 
-void OakFiles_WriteBool (struct OakFiles_Rider *r, BOOLEAN x) {
+void OakFiles_WriteBool (struct OakFiles__Rider *r, OOC_BOOLEAN x) {
   if (x == 1)
     OakFiles_Write(r,'\001');
   else
     OakFiles_Write(r,'\000');
 }
 
-void OakFiles_WriteInt (struct OakFiles_Rider *r, INTEGER x) {
-  WriteBytesSwap(r,(BYTE*)&x,sizeof(INTEGER));
+void OakFiles_WriteInt (struct OakFiles__Rider *r, INTEGER x) {
+  WriteBytesSwap(r,(OOC_BYTE*)&x,sizeof(INTEGER));
 }
 
-void OakFiles_WriteLInt (struct OakFiles_Rider *r, LONGINT x) {
-  WriteBytesSwap(r,(BYTE*)&x,sizeof(LONGINT));
+void OakFiles_WriteLInt (struct OakFiles__Rider *r, LONGINT x) {
+  WriteBytesSwap(r,(OOC_BYTE*)&x,sizeof(LONGINT));
 }
 
-void OakFiles_WriteLReal (struct OakFiles_Rider *r, LONGREAL x) {
-  WriteBytesSwap(r,(BYTE*)&x,sizeof(LONGREAL));
+void OakFiles_WriteLReal (struct OakFiles__Rider *r, LONGREAL x) {
+  WriteBytesSwap(r,(OOC_BYTE*)&x,sizeof(LONGREAL));
 }
 
-void OakFiles_WriteNum (struct OakFiles_Rider *r, LONGINT x) {
+void OakFiles_WriteNum (struct OakFiles__Rider *r, LONGINT x) {
   LONGINT m;
 
   while ((x< -64) || (x >63))
   {
     _mod(m, x, 128, LONGINT);
-    OakFiles_Write(r, (CHAR)(m+128));
+    OakFiles_Write(r, (OOC_CHAR)(m+128));
     _div(x, x, 128, LONGINT);
   }
   _mod(m, x, 128, LONGINT);
-  OakFiles_Write(r,(CHAR)m);
+  OakFiles_Write(r,(OOC_CHAR)m);
 }
 
-void OakFiles_WriteReal (struct OakFiles_Rider *r, REAL x) {
-  WriteBytesSwap(r,(BYTE*)&x,sizeof(REAL));
+void OakFiles_WriteReal (struct OakFiles__Rider *r, REAL x) {
+  WriteBytesSwap(r,(OOC_BYTE*)&x,sizeof(REAL));
 }
 
-void OakFiles_WriteSet (struct OakFiles_Rider *r, SET x) {
-  WriteBytesSwap(r,(BYTE*)&x,sizeof(SET));
+void OakFiles_WriteSet (struct OakFiles__Rider *r, SET x) {
+  WriteBytesSwap(r,(OOC_BYTE*)&x,sizeof(SET));
 }
 
-void OakFiles_WriteString (struct OakFiles_Rider *r, const CHAR *x) {
+void OakFiles_WriteString (struct OakFiles__Rider *r, const OOC_CHAR *x) {
   LONGINT i=-1;
   do {
     i++;
-    OakFiles_Write(r,(BYTE)x[i]);
+    OakFiles_Write(r,(OOC_BYTE)x[i]);
   } while (x[i] != '\000');
 }
 
-void OakFiles_Read (struct OakFiles_Rider *r, BYTE *x) {
-  OakFiles_ReadBytes(r,x,sizeof(BYTE));
+void OakFiles_Read (struct OakFiles__Rider *r, OOC_BYTE *x) {
+  OakFiles_ReadBytes(r,x,sizeof(OOC_BYTE));
 }
 
 
-void OakFiles_ReadBool (struct OakFiles_Rider *r, BOOLEAN *x) {
-  BYTE y;
+void OakFiles_ReadBool (struct OakFiles__Rider *r, OOC_BOOLEAN *x) {
+  OOC_BYTE y;
   OakFiles_Read(r,&y);
   if (y == 1)
     *x=1;
@@ -865,21 +895,21 @@ void OakFiles_ReadBool (struct OakFiles_Rider *r, BOOLEAN *x) {
     *x=0;
 }
 
-void OakFiles_ReadInt (struct OakFiles_Rider *r, INTEGER *x) {
-  ReadBytesSwap(r,(BYTE*)x,sizeof(INTEGER));
+void OakFiles_ReadInt (struct OakFiles__Rider *r, INTEGER *x) {
+  ReadBytesSwap(r,(OOC_BYTE*)x,sizeof(INTEGER));
 }
 
-void OakFiles_ReadLInt (struct OakFiles_Rider *r, LONGINT *x) {
-  ReadBytesSwap(r,(BYTE*)x,sizeof(LONGINT));
+void OakFiles_ReadLInt (struct OakFiles__Rider *r, LONGINT *x) {
+  ReadBytesSwap(r,(OOC_BYTE*)x,sizeof(LONGINT));
 }
 
-void OakFiles_ReadLReal (struct OakFiles_Rider *r, LONGREAL *x) {
-  ReadBytesSwap(r,(BYTE*)x,sizeof(LONGREAL));
+void OakFiles_ReadLReal (struct OakFiles__Rider *r, LONGREAL *x) {
+  ReadBytesSwap(r,(OOC_BYTE*)x,sizeof(LONGREAL));
 }
 
-void OakFiles_ReadNum (struct OakFiles_Rider *r, LONGINT *x) {
+void OakFiles_ReadNum (struct OakFiles__Rider *r, LONGINT *x) {
   SHORTINT s = 0;
-  CHAR ch;
+  OOC_CHAR ch;
   LONGINT n = 0;
 
   OakFiles_Read(r, &(ch));
@@ -904,15 +934,15 @@ void OakFiles_ReadNum (struct OakFiles_Rider *r, LONGINT *x) {
   }
 }
 
-void OakFiles_ReadReal (struct OakFiles_Rider *r, REAL *x) {
-  ReadBytesSwap(r,(BYTE*)x,sizeof(REAL));
+void OakFiles_ReadReal (struct OakFiles__Rider *r, REAL *x) {
+  ReadBytesSwap(r,(OOC_BYTE*)x,sizeof(REAL));
 }
 
-void OakFiles_ReadSet (struct OakFiles_Rider *r, SET *x) {
-  ReadBytesSwap(r,(BYTE*)x,sizeof(SET));
+void OakFiles_ReadSet (struct OakFiles__Rider *r, SET *x) {
+  ReadBytesSwap(r,(OOC_BYTE*)x,sizeof(SET));
 }
 
-void OakFiles_ReadString (struct OakFiles_Rider *r, CHAR *x) {
+void OakFiles_ReadString (struct OakFiles__Rider *r, OOC_CHAR *x) {
   LONGINT i = -1;
   do {
     i++;
@@ -934,7 +964,7 @@ void OakFiles_ReadString (struct OakFiles_Rider *r, CHAR *x) {
 #if USE_GC
 static void finalize(void *obj, void *client_data)
 {
-  CloseDown((OakFiles_File)obj);
+  CloseDown((OakFiles__File)obj);
 }
 #endif
 
@@ -946,10 +976,10 @@ void Cleanup(void) {
   }
 }
 
-void OakFiles__init (void) {
+void OakFiles_init (void) {
   INTEGER swapTest = 1;
   _mid = _register_module (&OakFiles__md.md, NULL);
-  InitSwap((BYTE*)&swapTest);
+  InitSwap((OOC_BYTE*)&swapTest);
   fdInUse = 0;
-  Termination_RegisterProc(Cleanup);
+  Termination__RegisterProc(Cleanup);
 }
